==> org-lsst-ccs-ui-3.0.0-sources.jar: org/lsst/ccs/gconsole/agent/command/CommandHandle.java <==
package org.lsst.ccs.gconsole.agent.command;

import java.util.concurrent.CancellationException;
import java.util.concurrent.TimeoutException;
import org.lsst.ccs.bus.messages.CommandAck;
import org.lsst.ccs.bus.messages.CommandNack;

/**
 * Interface to be implemented by classes that process responses to commands sent to remote subsystems.
 *
 * @author onoprien
 */
public interface CommandHandle  {
    
    /**
     * Called if the command cannot be sent to the target subsystem.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown while attempting to send the command.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onSendingFailure(Throwable exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called when an ACK is received.
     * @param ack ACK.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onAck(CommandAck ack, CommandTask source) {
    }
    
    /**
     * Called when the command is rejected.
     * The default implementation forwards the call to {@link #onResult}.
     * @param nack NACK.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onNack(CommandNack nack, CommandTask source) {
        onResult(nack, source);
    }        
    
    /**
     * Called when the command result that is not an exception is received.
     * The default implementation forwards the call to {@link #onResult}.
     * @param result Result.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onSuccess(Object result, CommandTask source) {
        onResult(result, source);
    }
    
    /**
     * Called when the command execution fails.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown while attempting to execute the command.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onExecutionFailure(Throwable exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called if the command times out.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onTimeout(TimeoutException exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called if the command is successfully canceled.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onCancel(CancellationException exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called when either the result of the command execution is received, or
     * the command is canceled or times out. This method is guaranteed to be 
     * called for every command unless one of the more specific handlers -
     * {@link #onNack}, {@link #onSuccess}, {@link #onExecutionFailure}, {@link #onTimeout}, {@link #onCancel}
     * - is implemented.
     * The default implementation does nothing.
     * 
     * @param result Result of the command submission. Either an object returned
     * by the target subsystem, or a locally generated {@code TimeoutException}
     * or {@code InterruptedException}.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onResult(Object result, CommandTask source) {
    }
    
}

==> org-lsst-ccs-ui-3.1.0-20190308.020151-13-sources.jar: org/lsst/ccs/gconsole/agent/command/CommandHandle.java <==
package org.lsst.ccs.gconsole.agent.command;

import java.util.concurrent.CancellationException;
import java.util.concurrent.TimeoutException;
import org.lsst.ccs.bus.messages.CommandAck;
import org.lsst.ccs.bus.messages.CommandNack;

/**
 * Interface to be implemented by classes that process responses to commands sent to remote subsystems.
 *
 * @author onoprien
 */
public interface CommandHandle  {
    
    /**
     * Empty {@code CommandHandle} that does no processing.
     */
    static public final CommandHandle NONE = new CommandHandle() {};
    
    /**
     * Called if the command cannot be sent to the target subsystem.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown while attempting to send the command.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onSendingFailure(Throwable exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called when an ACK is received.
     * @param ack ACK.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onAck(CommandAck ack, CommandTask source) {
    }
    
    /**
     * Called when the command is rejected.
     * The default implementation forwards the call to {@link #onResult}.
     * @param nack NACK.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onNack(CommandNack nack, CommandTask source) {
        onResult(nack, source);
    }        
    
    /**
     * Called when the command result that is not an exception is received.
     * The default implementation forwards the call to {@link #onResult}.
     * @param result Result.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onSuccess(Object result, CommandTask source) {
        onResult(result, source);
    }
    
    /**
     * Called when the target subsystem either throws an uncaught exception while trying
     * to execute the command, or returns an exception as the result of execution.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown while attempting to execute the command.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onExecutionFailure(Throwable exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called if the command times out.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onTimeout(TimeoutException exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called if the command is successfully canceled.
     * The default implementation forwards the call to {@link #onResult}.
     * @param exception Exception thrown.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onCancel(CancellationException exception, CommandTask source) {
        onResult(exception, source);
    }
    
    /**
     * Called when either the result of the command execution is received, or
     * the command is canceled or times out. This method is guaranteed to be 
     * called for every command unless one of the more specific handlers -
     * {@link #onNack}, {@link #onSuccess}, {@link #onExecutionFailure}, {@link #onTimeout}, {@link #onCancel}
     * - is implemented.
     * The default implementation does nothing.
     * 
     * @param result Result of the command submission. Either an object returned
     * by the target subsystem, or a locally generated {@code TimeoutException}
     * or {@code InterruptedException}.
     * @param source {@code CommandTask} that executed the command.
     */
    default void onResult(Object result, CommandTask source) {
    }
    
}
